@@ -10,6 +10,8 @@ import warnings
 from dataclasses import dataclass
 from typing import Any, Callable, Dict, List, Optional
 
+import requests
+
 from annofabapi import AnnofabApi
 from annofabapi.exceptions import AnnofabApiException
 from annofabapi.models import (
@@ -623,6 +625,93 @@ class Wrapper:
     #########################################
     # Public Method : Statistics
     #########################################
+    def _request_location_header_url(self, response: requests.Response) -> Any:
+        """
+        Location headerに記載されているURLの中身を返す。
+
+        Args:
+            response:
+
+        Returns:
+            Location headerに記載されているURLの中身
+
+        """
+        url = response.headers["Location"]
+
+        response = self.api.session.get(url)
+        _log_error_response(logger, response)
+
+        response.encoding = "utf-8"
+        _raise_for_status(response)
+        content = self.api._response_to_content(response)
+        return content
+
+    def get_task_statistics(self, project_id: str) -> List[Any]:
+        """
+        getTaskStatistics APIのLocation headerの中身を返す。
+
+        Args:
+            project_id:  プロジェクトID
+
+        Returns:
+
+
+        """
+        _, response = self.api.get_task_statistics(project_id)
+        return self._request_location_header_url(response)
+
+    def get_account_statistics(self, project_id: str) -> List[Any]:
+        """
+        getAccountStatistics APIのLocation headerの中身を返す。
+
+        Args:
+            project_id:
+
+        Returns:
+
+        """
+        _, response = self.api.get_account_statistics(project_id)
+        return self._request_location_header_url(response)
+
+    def get_inspection_statistics(self, project_id: str) -> List[Any]:
+        """
+        getInspectionStatistics APIのLocation headerの中身を返す。
+
+        Args:
+            project_id:
+
+        Returns:
+
+        """
+        _, response = self.api.get_inspection_statistics(project_id)
+        return self._request_location_header_url(response)
+
+    def get_task_phase_statistics(self, project_id: str) -> List[Any]:
+        """
+        getTaskPhaseStatistics APIのLocation headerの中身を返す。
+
+        Args:
+            project_id:
+
+        Returns:
+
+        """
+        _, response = self.api.get_task_phase_statistics(project_id)
+        return self._request_location_header_url(response)
+
+    def get_label_statistics(self, project_id: str) -> List[Any]:
+        """
+        getLabelStatistics APIのLocation headerの中身を返す。
+
+        Args:
+            project_id:
+
+        Returns:
+
+        """
+        _, response = self.api.get_label_statistics(project_id)
+        return self._request_location_header_url(response)
+
     def get_worktime_statistics(self, project_id: str) -> List[Any]:
         """
         タスク作業時間集計取得.
@@ -636,15 +725,7 @@ class Wrapper:
 
         """
         _, response = self.api.get_worktime_statistics(project_id)
-        url = response.headers["Location"]
-
-        response = self.api.session.get(url)
-        _log_error_response(logger, response)
-
-        response.encoding = "utf-8"
-        _raise_for_status(response)
-        content = self.api._response_to_content(response)
-        return content
+        return self._request_location_header_url(response)
 
     #########################################
     # Public Method : Supplementary
